# Changelogs

## Latest Changes

## 0.0.1

### :sparkles: Features

- :dart: feat: initial the first project structure. (_2024-05-04_)

### :black_nib: Code Changes

- :construction: refactored: Initial commit (_2024-03-21_)

### :card_file_box: Documents

- :page_facing_up: docs: update readme file and adjust version for bump tag. (_2024-05-04_)
- :page_facing_up: docs: update readme file and add base folder structure (_2024-05-03_)

### :package: Build & Workflow

- :toolbox: build: add github workflow for test and publish. (_2024-05-04_)

